@@ -97,19 +97,26 @@ void Titraqform::setupPrefs(void)
         if (!Homedir.isEmpty())
             m_pPrefs->setString(TITRAQ_PREFHOME, Homedir);
         else
-            m_pPrefs->setString(TITRAQ_PREFHOME, TITRAQ_DEFUSER);
+            m_pPrefs->setString(TITRAQ_PREFHOME, TITRAQ_DEFHOME);
         if (!Username.isEmpty())
             m_pPrefs->setString(TITRAQ_PREFUSER, Username);
         else
             m_pPrefs->setString(TITRAQ_PREFUSER, TITRAQ_DEFUSER);
+
+        m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
         m_pPrefs->setString(TITRAQ_PREFACCOUNTS, TITRAQ_DEFACCOUNTS);
         m_pPrefs->setString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
-        m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
         m_pPrefs->setString(TITRAQ_PREFVIEW, TITRAQ_DEFVIEW);
         m_pPrefs->setNumber(TITRAQ_PREFSORTCOL, TITRAQ_DEFSORTCOL);
         m_pPrefs->setBool(TITRAQ_PREFSORTDIR, TITRAQ_DEFSORTDIR);
         m_pPrefs->setString(TITRAQ_PREFREMOTELOG, TITRAQ_DEFREMOTELOG);
         m_pPrefs->setString(TITRAQ_PREFLOCALLOG, TITRAQ_DEFLOCALLOG);
+        m_pPrefs->setString(TITRAQ_PREFCORBHOST, TITRAQ_DEFCORBHOST);
+        m_pPrefs->setString(TITRAQ_PREFSOAPHOST, TITRAQ_DEFSOAPHOST);
+        m_pPrefs->setBool(TITRAQ_PREFCORBON, TITRAQ_DEFCORBON);
+        m_pPrefs->setBool(TITRAQ_PREFSOAPON, TITRAQ_DEFSOAPON);
+        m_pPrefs->setBool(TITRAQ_PREFBAKON, TITRAQ_DEFBAKON);
+        m_pPrefs->setBool(TITRAQ_PREFEXTENDON, TITRAQ_DEFEXTENDON);
         m_pPrefs->flush();  // Write the new conf file
         QTextStream cerr(stderr, IO_WriteOnly);
         cerr << trUtf8("Created new preferences file ") << Homedir << QChar('/')
