@@ -38,7 +38,7 @@
 #define TITRAQ_APPTITLE         "AS Accounting System"
 #define TITRAQ_STR_ID           "OSSPASGUI"                         /* APPID */
 #define TITRAQ_UID_ID           0x84fae747e1a64016bf049e98bbc4bd96  /* UUID */
-#define TITRAQ_PREFVER          "0.5"
+#define TITRAQ_PREFVER          "0.6"
 #define TITRAQ_PREFHOME         "homedir"
 #define TITRAQ_DEFHOME          "."
 #define TITRAQ_PREFUSER         "user"
@@ -54,6 +54,18 @@
 #define TITRAQ_DEFREMOTELOG     "no"
 #define TITRAQ_PREFLOCALLOG     "loglocal"
 #define TITRAQ_DEFLOCALLOG      "no"
+#define TITRAQ_PREFCORBHOST     "corbahost"
+#define TITRAQ_DEFCORBHOST      "localhost"
+#define TITRAQ_PREFSOAPHOST     "soaphost"
+#define TITRAQ_DEFSOAPHOST      "localhost"
+#define TITRAQ_PREFCORBON       "corbaenable"
+#define TITRAQ_DEFCORBON        0
+#define TITRAQ_PREFSOAPON       "soapenable"
+#define TITRAQ_DEFSOAPON        0
+#define TITRAQ_PREFBAKON        "autobackup"
+#define TITRAQ_DEFBAKON         1
+#define TITRAQ_PREFEXTENDON     "filextension"
+#define TITRAQ_DEFEXTENDON      1
 
 // Column show preferences
 #define TITRAQ_PREFSTATCOLON    "statcolshow"
@@ -138,6 +150,14 @@
 #define TITRAQ_ENVUSERNAME      "USER"
 #define TITRAQ_ENVHOMEDIR       "HOME"
 
+// Style string constants
+#define TITRAQ_STRCDE           "CDE"
+#define TITRAQ_STRSGI           "SGI"
+#define TITRAQ_STRMOTIF         "Motfi"
+#define TITRAQ_STRMPLUS         "MotifPlus"
+#define TITRAQ_STRPLAT          "Platinum"
+#define TITRAQ_STRMSOFT         "Windows"
+
 // Other string constants
 #define TITRAQ_SEPARATORTOK     " "
 #define TITRAQ_HOMEDIRTOK       "~/"
